% Model of a solar collector
%
% Written by Thorsten Stuetzle

function xdot = solarmodel(x,t)

%
% The sun-collector model
%

% Number of elements for distributed systems:
i_0 = 20;

% Initializing variables:

global uk; 
%global wk;

% Flowrate:
m_dot = uk;
% m_dot = 5.415;
% m_dot = 5.985;

% Density:
rho = 800;

% specific heat capacity:
c_p = 3000;

% weather factor:
F = 1;

% width of collector:
W = 5;

% length of collector:
L = 790;

% heat transfer coefficient of collector tube:
U_1 = 50;

% Diameter of collector tube:
D_1 = 0.07;

% heat transfer coefficient of the back tube:
U_3 = U_1;

% Diameter of the back tube:
D_3 = D_1;

% Sun intensity

S = [];
for i = 1:i_0
  S = [S; 1000];
end


% ambient Temperature

T_amb = [];
for i = 1:i_0
  T_amb = [T_amb; 303.15];
end

% Water Temperature

T_water = 375.15;

% Length of one discrete element:
delta_z = L/i_0;



% let's build the Jacobian matrix:

alpha = 4*m_dot/(rho*pi*D_1*D_1);

beta = (4*F*U_1)/(c_p*rho*D_1);

gamma = (4*F*W)/(c_p*rho*pi*D_1*D_1);

K1 = 1;

K2 = 5;

nue = (4*m_dot)/(rho*pi*D_3*D_3);


H = zeros(2*i_0+1);

for i = 1:i_0
  H(i,i) = -alpha/delta_z - beta;
  if (i-1) > 0
    H(i,i-1) = alpha/delta_z;
  end
end

H(1,2*i_0+1) = alpha/delta_z;

H(i_0+1,i_0) = K1;

H(i_0+1,i_0+1) = -(K1+K2);

for i = (i_0+1):(2*i_0)
   H(i+1,i) = nue/delta_z;
   H(i+1,i+1) = -nue/delta_z;
end


% let's build the b-vector

b = zeros(2*i_0+1,1);

for i = 1:i_0
  b(i) = gamma*S(i,1) + beta*T_amb(i,1);
end

b(i_0+1) = K2*T_water;


xdot = H*x + b; 















